import sys
import base64

file = open(sys.argv[0], 'r').read()
if file == "":
    sys.exit()
file = file.replace("from pytobase import encode\n", "").replace("from pytobase import *\n", "")
filew = open(sys.argv[0], 'w')
enfile = base64.b64encode(file.encode())
filew.write(f"import pytobase\n'{enfile.decode()}'")


import base64
import sys

if __name__ != "__main__" and len(sys.argv) < 2 and "-m" not in sys.argv:
    try:
        file = open(sys.argv[0], 'r').read()
        file = file.replace('import pytobase\n', '').replace(file[-1], '')
        exec(base64.b64decode(file.encode()).decode())
    except Exception as e:
        print(e)

elif len(sys.argv) > 1 and sys.argv[1] == "encode":
    file = open(sys.argv[2], 'r').read()
    file = file.replace("from pytobase import encode\n", "").replace("from pytobase import *\n", "")
    filew = open(sys.argv[2], 'w')
    enfile = base64.b64encode(file.encode())
    filew.write(f"import pytobase\n'{enfile.decode()}'")
else:
    print('Usage: python3 -m pytobase encode file.py')



from setuptools import setup, find_packages
import os
os.system('export PYTHONPATH=~/module')

def readme():
  with open('README.md', 'r') as f:
    return f.read()


setup(
  name='pytobase',
  version='0.0.1',
  author='Zailox',
  author_email='zailox@mail.ru',
  description='This module will help you encrypt a python file using base64 encoding',
  long_description=readme(),
  long_description_content_type='text/markdown',
#  url='',
  packages=find_packages(),
  install_requires=[],
  classifiers=[
    'Programming Language :: Python :: 3.11',
    'License :: OSI Approved :: MIT License',
    'Operating System :: OS Independent'
  ],
  keywords='files speedfiles ',
#  project_urls={
 #   'GitHub': 'ZailoxTT'
  #},
  python_requires='>=3.6'
)